@@ -48,7 +48,6 @@ mkdir -p $DC_INSTALL_DIR/plugins
 mkdir -p $DC_INSTALL_DIR/plugins/wcx
 mkdir -p $DC_INSTALL_DIR/plugins/wcx/cpio
 mkdir -p $DC_INSTALL_DIR/plugins/wcx/deb
-mkdir -p $DC_INSTALL_DIR/plugins/wcx/lzma
 mkdir -p $DC_INSTALL_DIR/plugins/wcx/rpm
 mkdir -p $DC_INSTALL_DIR/plugins/wcx/unrar
 mkdir -p $DC_INSTALL_DIR/plugins/wcx/zip
@@ -80,7 +79,6 @@ cp -a multiarc.ini                 $DC_INSTALL_DIR/
 # WCX
 install -m 644 plugins/wcx/cpio/lib/cpio.wcx        $DC_INSTALL_DIR/plugins/wcx/cpio/
 install -m 644 plugins/wcx/deb/lib/deb.wcx          $DC_INSTALL_DIR/plugins/wcx/deb/
-install -m 644 plugins/wcx/lzma/lib/lzma.wcx        $DC_INSTALL_DIR/plugins/wcx/lzma/
 install -m 644 plugins/wcx/rpm/lib/rpm.wcx          $DC_INSTALL_DIR/plugins/wcx/rpm/
 install -m 644 plugins/wcx/unrar/lib/unrar.wcx      $DC_INSTALL_DIR/plugins/wcx/unrar/
 install -m 644 plugins/wcx/zip/lib/zip.wcx          $DC_INSTALL_DIR/plugins/wcx/zip/
@@ -112,6 +110,8 @@ if [ -z $CK_PORTABLE ]
     install -d                $DC_INSTALL_PREFIX/usr/share/doublecmd/doc
     install -m 644 doc/*.txt  $DC_INSTALL_PREFIX/usr/share/doublecmd/doc
     ln -sf ../../share/doublecmd/doc $DC_INSTALL_DIR/doc
+    # Copy scripts
+    cp -r scripts $DC_INSTALL_DIR/
     # Copy languages
     cp -r language $DC_INSTALL_PREFIX/usr/share/doublecmd
     ln -sf ../../share/doublecmd/language $DC_INSTALL_DIR/language
@@ -135,6 +135,7 @@ if [ -z $CK_PORTABLE ]
     # Copy directories
     cp -r language $DC_INSTALL_DIR/
     cp -r pixmaps  $DC_INSTALL_DIR/
+    cp -r scripts  $DC_INSTALL_DIR/
     # Copy libraries
     install -m 644 *.so*    $DC_INSTALL_DIR/
     # Copy DC icon
