@@ -3,7 +3,7 @@
 # This script updates Double Commander Open Build Service (OBS) repository
 
 # Set Double Commander version
-DC_VER=0.5.11
+DC_VER=0.6.1
 
 # Temp directory
 DC_TEMP_DIR=/var/tmp/doublecmd-$(date +%y.%m.%d)
@@ -33,7 +33,7 @@ update_doublecmd()
   # Remove help files
   rm -rf $DC_SOURCE_DIR/doc/en
   rm -rf $DC_SOURCE_DIR/doc/ru
-  rm -rf $DC_SOURCE_DIR/doc/uk_UA
+  rm -rf $DC_SOURCE_DIR/doc/uk
 
   # Prepare doublecmd-*.spec file
   cp -a rpm/doublecmd-*.spec $DC_TEMP_DIR
@@ -85,6 +85,8 @@ update_doublecmd_svn()
   curl -u Alexx2000:$PASSWORD -X POST https://api.opensuse.org/source/home:Alexx2000:doublecmd-svn/doublecmd-qt?cmd=runservice
   echo "Update Double Commander (Gtk)"
   curl -u Alexx2000:$PASSWORD -X POST https://api.opensuse.org/source/home:Alexx2000:doublecmd-svn/doublecmd-gtk?cmd=runservice
+  echo "Update Double Commander (Debian)"
+  curl -u Alexx2000:$PASSWORD -X POST https://api.opensuse.org/source/home:Alexx2000:doublecmd-svn/doublecmd-deb?cmd=runservice
   exit 0
 }
 
