@@ -3,9 +3,9 @@
 # This script updates Double Commander Personal Package Archive (PPA) repository
 
 # Set Double Commander version
-DC_VER=0.5.11
+DC_VER=0.6.1
 # Set Ubuntu series
-DISTRO=( precise trusty utopic )
+DISTRO=( trusty utopic vivid )
 
 # Temp directory
 DC_TEMP_DIR=/var/tmp/doublecmd-$(date +%y.%m.%d)
@@ -29,7 +29,7 @@ update_doublecmd()
   # Remove help files
   rm -rf $DC_SOURCE_DIR/doc/en
   rm -rf $DC_SOURCE_DIR/doc/ru
-  rm -rf $DC_SOURCE_DIR/doc/uk_UA
+  rm -rf $DC_SOURCE_DIR/doc/uk
 
   # Create doublecmd-x.x.x.orig.tar.gz
   pushd $DC_SOURCE_DIR/..
@@ -71,7 +71,7 @@ update_doublecmd_svn()
   # Remove help files
   rm -rf $DC_SOURCE_DIR/doc/en
   rm -rf $DC_SOURCE_DIR/doc/ru
-  rm -rf $DC_SOURCE_DIR/doc/uk_UA
+  rm -rf $DC_SOURCE_DIR/doc/uk
 
   # Prepare debian directory
   mkdir -p $DC_SOURCE_DIR/debian
